package labyrinth;

import javax.microedition.lcdui.Alert;
import javax.microedition.lcdui.Display;
import javax.microedition.lcdui.List;
import javax.microedition.midlet.MIDlet;
import javax.microedition.midlet.MIDletStateChangeException;

import labyrinth.menu.LabyrinthMenu;
import labyrinth.settings.GameSettings;

/*
 * Classe principal do sistema,  atravs dela que o sistema  inicializado.
 * Essa classe  responsvel pelo controle do estado atual do sistema, o qual
 * poder estar rodando, pausado ou inativo. Estende da classe MIDlet.
 */
public class Labyrinth extends MIDlet{

	/**
	 * Atributo que contm o que est sendo visualizado pelo usurio.
	 */
	protected Display display;

	/**
	 * Atributo que altera e configura um jogo.
	 */
	private GameSettings gameSettings;

	/**
	 * Contrutor que instancia um novo objeto desta classe.
	 */
	
	public Labyrinth() {
		super();
	}

	/**
	 * Mtodo que inicia o sistema, colocando-o no estado ativo.
	 * 
	 * @throws MIDletStateChangeException
	 */
	protected void startApp() throws MIDletStateChangeException {
		this.getAppProperty("labyrinth.Labyrinth");
		display = Display.getDisplay(this);
		LabyrinthMenu labyrinth = new LabyrinthMenu(this);
		display.setCurrent(labyrinth);
	}

	/**
	 * Mtodo que  executado quando o sistema entra no estado de pausa.
	 */
	protected void pauseApp() {
		
	}

	/**
	 * Mtodo que finaliza o sistema.
	 * 
	 * @param arg0
	 *            se true finaliza e libera todos os recursos, se false lana a
	 *            exceo informando que no quer ser destrudo nesse instante.
	 */
	protected void destroyApp(boolean arg0) throws MIDletStateChangeException {
		notifyDestroyed();
	}

	/**
	 * Mtodo que modifica a tela atual.
	 */
	public void ScreenShow(Alert alert, List menu) {
		if (alert == null) {
			display.setCurrent(menu);
		} else {
			display.setCurrent(alert, menu);
		}
	}

	/**
	 * Mtodo que mostra a tela de finalizao do sistema.
	 */
	public void ScreenExit() {
		try {
			this.destroyApp(true);
		} catch (MIDletStateChangeException e) {

			e.printStackTrace();
		}
	}

	/**
	 * Mtodo que  executado quando o sistema  interrompido por uma chamada,
	 * salvando todas as configuraes do jogo.
	 */
	/*public void call() {

	}*/

	/**
	 * Mtodo que salva as configuraes do jogo.
	 */
	/*public void saveSettings() {

	}*/

	/**
	 * @return retorna o gameSettings.
	 */
	public GameSettings getGameSettings() {
		return gameSettings;
	}

	/**
	 * Mtodo que retorna o atributo display.
	 * 
	 * @return Returns atributo display.
	 */
	public Display getDisplay() {
		return display;
	}
}