package labyrinth.game;

import labyrinth.settings.GameSettings;
import labyrinth.settings.constants.LabyrinthConstants1;

public class Game {
	private String labyrinth;

	private String[] labyrinthMapper;

	private int time;

	private boolean screen2;

	private int x;

	private int y;

	private byte stage;

	private int score;

	private byte lives;

	private GameSettings gameSettings;

	public Game(String labyrinth) {
		this.gameSettings = new GameSettings();
		this.setLabyrinth(labyrinth);
		this.setInitialPositions();
		this.time = 0;
		this.initializeTimer();
		this.screen2 = false;
		this.stage = 1;
		this.score = 0;
		this.lives = 2;
	}

	public Game(GameSettings gs) {
		this.gameSettings = gs;
		this.setLabyrinth(gs.getMap());
		this.lives = gs.getLives();
		this.score = gs.getScore();
		this.screen2 = gs.isScreen2();
		this.stage = gs.getStage();
		this.time = gs.getTime();
		this.x = gs.getXPosition();
		this.y = gs.getYPosition();
	}

	/***************************************************************************
	 * O mtodo initializeTimer() inicializa o tempo estabelecido para a fase.
	 **************************************************************************/
	public void initializeTimer() {
		if (this.gameSettings.getLevel() == 1) {
			this.time = LabyrinthConstants1.TIME;
		} else if (this.gameSettings.getLevel() == 2) {
			this.time = LabyrinthConstants1.TIME
					- (this.gameSettings.getLevel() * 10);
		} else {
			this.time = LabyrinthConstants1.TIME
					- (this.gameSettings.getLevel() * 10);
		}

		if (this.getStage() == 2) {
			this.time = this.time + (this.gameSettings.getLevel() * 10);
		} else if (this.getStage() == 3) {
			this.time = this.time + (this.gameSettings.getLevel() * 10);
		}
	}

	/***************************************************************************
	 * O mtodo getInitialMapper(String labyrinth) retorna o mapa que possui o
	 * nome passado no parametro do metodo.
	 **************************************************************************/
	/*
	 * public byte[][] getInitialMapper(String labyrinth) { byte[][] result =
	 * null; if (labyrinth != null) { } else { } return result; }
	 */

	/***************************************************************************
	 * O mtodo getLabyrinthMapper() retorna o mapa contido no atributo
	 * labyrinthMapper.
	 **************************************************************************/
	public String[] getLabyrinthMapper() {
		return this.labyrinthMapper;
	}

	/***************************************************************************
	 * O mtodo getLabyrinth() retorna o labirinto contido no atributo
	 * labyrinth.
	 **************************************************************************/
	public String getLabyrinth() {
		return this.labyrinth;
	}

	/***************************************************************************
	 * O mtodo getTime() retorna o tempo contido no atributo time.
	 **************************************************************************/
	public int getTime() {
		return this.time;
	}

	/***************************************************************************
	 * O mtodo getXPosition() retorna a posicao x do jogador contida no
	 * atributo x.
	 **************************************************************************/
	public int getXPosition() {
		return this.x;
	}

	/***************************************************************************
	 * O mtodo getYPosition() retorna a posicao x do jogador contida no
	 * atributo y.
	 **************************************************************************/
	public int getYPosition() {
		return this.y;
	}

	/***************************************************************************
	 * O mtodo getStage() retorna o byte contido no atributo stage.
	 **************************************************************************/

	public byte getStage() {
		return this.stage;
	}

	/***************************************************************************
	 * O mtodo getScore() retorna o score do jogador contido no atributo score.
	 **************************************************************************/
	public int getScore() {
		return this.score;
	}

	/***************************************************************************
	 * O mtodo getLives() retorna o numero de vidas do jogador contido no
	 * atributo lives.
	 **************************************************************************/
	public byte getLives() {
		return this.lives;
	}

	/***************************************************************************
	 * O mtodo setLabyrinth(String lab) modifica o conteudo do atributo
	 * labyrinth.
	 **************************************************************************/
	public void setLabyrinth(String lab) {
		if (lab != null) {
			this.labyrinth = lab;
			this.labyrinthMapper = null;
			this.setLabyrinthMapper(LabyrinthsMatrix.getMatrix(lab));
		} else {
		}
	}

	/***************************************************************************
	 * O mtodo setLabyrinth(byte[][] lab) modifica o conteudo do atributo
	 * labyrinthMapper.
	 **************************************************************************/
	public void setLabyrinthMapper(String[] lab) {
		if (lab != null) {
			this.labyrinthMapper = lab;
		} else {
		}
	}

	/***************************************************************************
	 * O mtodo setLabyrinth(int time) modifica o conteudo do atributo time.
	 **************************************************************************/
	public void setTime(int time) {
		this.time = time;
	}

	/***************************************************************************
	 * O mtodo setLabyrinth(String lab) modifica o conteudo do atributo x.
	 **************************************************************************/
	public void setXPosition(int x) {
		this.x = x;
	}

	/***************************************************************************
	 * O mtodo setLabyrinth(String lab) modifica o conteudo do atributo y.
	 **************************************************************************/
	public void setYPosition(int y) {
		this.y = y;
	}

	/***************************************************************************
	 * O mtodo setLabyrinth(String lab) modifica o conteudo do atributo stage.
	 **************************************************************************/
	public void setstage(byte stage) {
		this.stage = stage;
	}

	/***************************************************************************
	 * O mtodo setLabyrinth(String lab) modifica o conteudo do atributo score.
	 **************************************************************************/
	public void setScore(int score) {
		this.score = score;
	}

	/***************************************************************************
	 * O mtodo setLabyrinth(String lab) modifica o conteudo do atributo lives.
	 **************************************************************************/
	public void setLives(byte lives) {
		this.lives = lives;
	}

	/***************************************************************************
	 * O mtodo incstage() adiciona 1 ao conteudo do atributo stage.
	 **************************************************************************/
	public void incStage() {
		this.stage = Byte.parseByte("" + ((this.getStage() + 1)));
	}

	/***************************************************************************
	 * O mtodo decTimer() decrementa o time do jogo
	 **************************************************************************/
	public void decTimer() {
		this.time--;
	}

	/***************************************************************************
	 * O mtodo decLives() decrementa em 1 o numero de vidas do jogador.
	 **************************************************************************/
	public void decLives() {
		this.lives = Byte.parseByte("" + (this.lives - 1));
		this.initializeTimer();
	}

	//**************************************MODIFIQUEI !! MAAG
	// ***********************
	/***************************************************************************
	 * O mtodo colision(int x, int y) verifica se houve colisao do jogador com
	 * alguma parede.
	 **************************************************************************/
	public boolean colision(int x, int y, int direction, GameScreen gs) {
		boolean colision = false;

		if ((x < 0) || (x >= 64) || (y < 0) || (y >= 32)
				|| (this.labyrinthMapper[y].charAt(x) == '1')
				|| (this.labyrinthMapper[y + 1].charAt(x) == '1')
				|| (this.labyrinthMapper[y].charAt(x + 1) == '1')
				|| (this.labyrinthMapper[y + 1].charAt(x + 1) == '1')) {
			colision = true;
		}

		if (!colision) {
			this.setXPosition(x);
			this.setYPosition(y);
			if (!this.winLevel()) {
				if (this.getXPosition() >= 30) {
					if ((this.getXPosition() == 30)
							|| (this.getXPosition() == 31)) {
						if ((this.labyrinthMapper[y].charAt(30) == '0')
								&& (this.labyrinthMapper[y + 1].charAt(30) == '0')
								&& (this.labyrinthMapper[y].charAt(31) == '0')
								&& (this.labyrinthMapper[y + 1].charAt(31) == '0')) {
							this.setXPosition(32);

							this.setScreen2(true);
							gs.setBackground();
						}

					} else {

						if (this.getXPosition() == 32) {
							if ((this.labyrinthMapper[y].charAt(32) == '0')
									&& (this.labyrinthMapper[y + 1].charAt(33) == '0')
									&& (this.labyrinthMapper[y].charAt(32) == '0')
									&& (this.labyrinthMapper[y + 1].charAt(32) == '0')) {
								this.setXPosition(30);
								this.setScreen2(false);
								gs.setBackground();
							}

						}
					}

				}
			} else {

				//this.gameSettings.setLevel(Byte.parseByte(""+((this.gameSettings.getLevel()
				// +1))));
			}
		}

		return colision;
	}

	/***************************************************************************
	 * O mtodo winLevel() verifica se o jogador venceu a fase.
	 **************************************************************************/
	public boolean winLevel() {
		boolean levelWon = false;
		if ((this.labyrinthMapper[this.getYPosition()].charAt(this.getXPosition()) == '2')
				&& (this.labyrinthMapper[this.getYPosition() + 1].charAt(this
						.getXPosition()) == '2')
				&& (this.labyrinthMapper[this.getYPosition()].charAt(this
						.getXPosition() + 1) == '2')
				&& (this.labyrinthMapper[this.getYPosition() + 1].charAt(this
						.getXPosition() + 1) == '2')) {
			levelWon = true;
		}
		return levelWon;
	}

	/***************************************************************************
	 * O mtodo winGame() verifica se o jogador venceu o jogo.
	 **************************************************************************/
	public boolean winGame() {
		boolean retorno = false;
		if (this.stage == 3) {
			if (this.winLevel()) {
				retorno = true;
			}
		}

		return retorno;
	}

	/***************************************************************************
	 * O mtodo lostLive() verifica se o jogador perdeu vida.
	 **************************************************************************/
	public boolean lostLive() {
		boolean retorno = false;
		return retorno;
	}

	/***************************************************************************
	 * O mtodo lostGame() verifica se o jogador perdeu o jogo.
	 **************************************************************************/
	public boolean lostGame() {
		boolean retorno = (this.lives == 0);
		return retorno;
	}

	/***************************************************************************
	 * O mtodo initializeSound() inicializa o som do jogo.
	 **************************************************************************/
	/*public void initializeSound() {
	}*/

	/***************************************************************************
	 * O mtodo stopSound interrompe a execucao do som.
	 **************************************************************************/
	/*public void stopSound() {
	}*/

	/***************************************************************************
	 * O mtodo initializeVibration() inicializa o a vibracao do aparelho.
	 **************************************************************************/
	/*public void initializeVibration() {
	}*/

	/***************************************************************************
	 * O mtodo stopVibration() interrompe a execucao da vibracao do aparelho.
	 **************************************************************************/
/*	public void stopVibration() {
	}*/

	//	********************************* ADICIONAR AO DOCUMENTO DE CLASSES
	// *****************
	/** ************************ modifiquei aki - maag */
	/***************************************************************************
	 * O mtodo stopVibration() obtem a posicao inicial do sprite
	 **************************************************************************/
	public void setInitialPositions() {
		boolean find = false;
		for (int i = 0; (i < 64) && !find; i++) {
			for (int j = 0; (j < 32) && !find; j++) {
				if (this.labyrinthMapper[j].charAt(i) == '0') {
					this.setXPosition(i);
					this.setYPosition(j);
					find = true;
				}
			}
		}		
	}

	/**
	 * @return Returns the screen2.
	 */
	public boolean isScreen2() {
		return this.screen2;
	}

	/**
	 * @param screen2
	 *            The screen2 to set.
	 */
	public void setScreen2(boolean screen2) {
		this.screen2 = screen2;
	}

	public void incScore() {
		this.setScore(this.getScore()
				+ (this.time * Integer.parseInt("" + this.getStage()) * 3));
	}

	/**
	 * @return Returns the gameSettings.
	 */
	public GameSettings getGameSettings() {
		return gameSettings;
	}
}