package labyrinth.menu;

import java.io.IOException;

import javax.microedition.lcdui.Font;
import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.Image;

import labyrinth.records.Record;
import labyrinth.records.RecordRegistry;

import com.nokia.mid.ui.FullCanvas;

/*
 * Classe responsvel por mostrar ao usurio os maiores recordes obtidos no
 * jogo, iniciais do jogador e pontuao. Todos os recordes so obtidos de um
 * arquivo onde esto salvos as iniciais e pontuao dos jogadores.
 */
public class RecordsScreen extends FullCanvas {

	/**
	 * Atributo que contm os recordes do jogo.
	 */
	private RecordRegistry records;

	/**
	 * Atributo que contm o MIDlet ativo do sistema.
	 */
	private LabyrinthMenu main;

	/**
	 * Atributo que contem uma imagem a ser impressa.
	 */
	private Image fundo;

	/**
	 * Atributo que indica se um novo score ser adicionado a tela
	 */
	private boolean isNewRecord;

	/**
	 * Atributo que indica o novo score a ser adicionado
	 */
	private int newScore;

	/**
	 * Atributo que armazena o nome do jogador a obter o ltimo recorde
	 */
	private String newName="     ";

	private char[] letters = { ' ','A', 'B', 'C', 'D', 'E', 'F', 'G', 'H', 'I',
			'J', 'K', 'L', 'M', 'N', 'O', 'P', 'Q', 'R', 'S', 'T', 'U', 'V',
			'W', 'X', 'Y', 'Z', '1', '2', '3', '4', '5', '6', '7', '8', '9',
			'0', '*', '.', '/', '\\', '(', ')', '-', '_', '&' };

	private int cursorPosition;

	private int characterPosition;

	private Image cursor;

	/**
	 * construtor que instancia um objeto da classe.
	 */
	public RecordsScreen(LabyrinthMenu m) {

		try {

			main = m;
			records = new RecordRegistry("records");
			fundo = null;
			cursor = null;
			
			
			
			this.setNewRecord(false);
			

			repaint();

		} catch (IllegalArgumentException e) {
			e.printStackTrace();
		} catch (NullPointerException e) {
			e.printStackTrace();
		}
	}

	public RecordsScreen(LabyrinthMenu m, int score, RecordRegistry recordReg) {

		try {

			main = m;
			records = recordReg;
			fundo = null;
			
			this.setNewScore(score);
			this.setNewRecord(true);
			cursor = null;
			
			repaint();
			

		} catch (IllegalArgumentException e) {
			e.printStackTrace();
		} catch (NullPointerException e) {
			e.printStackTrace();
		} 
	}

	/**
	 * Mtodo que pinta na tela o placar dos recordes.
	 * 
	 * @param graphic
	 *            objeto que ser pintado na tela.
	 */
	public void paint(Graphics graphic) {
		try{
			
			graphic.setColor(0, 0, 0);
			
			graphic.fillRect(0, 118, 128, 10);
			
		graphic.setFont(Font.getFont(Font.FACE_MONOSPACE, Font.STYLE_PLAIN,
				Font.SIZE_SMALL));
		graphic.setColor(255, 255, 255);

		//graphic.setFont(Font.getFont(Font.FACE_MONOSPACE, Font.STYLE_ITALIC,
		// Font.SIZE_MEDIUM));
		this.fundo = Image.createImage("/labyrinth/images/default.png");
		graphic.drawImage(this.fundo, 0, 0, Graphics.LEFT | Graphics.TOP);
		this.fundo = null;
		System.gc();
		int index = 0;
		int x1 = 5;
		int x2 = 123;
		int y = 45;
		int indexScore = this.records.getNewRecordIndex(this.getNewScore());
		if (this.records.getRecords().getRepository().size() != 0) {
			this.cursor = Image.createImage("/labyrinth/images/setas.png");
			while (index < 5) {
				Record temp = null;
				if (this.isNewRecord() && index == indexScore) {
					
					this.drawCursor(x1,y,graphic);
					graphic.drawString("" + this.newScore, x2, y, Graphics.RIGHT
							| Graphics.TOP);
					
					Font f = graphic.getFont();
					
					y = y + f.getHeight()+2;
					
					while(index < 5){
						if (this.records.getRecords().getRepository().size()> index){
							temp = (Record) this.records.getRecords()
							.getRepository().elementAt(index);
							graphic.drawString(temp.getName(), x1, y, Graphics.LEFT
									| Graphics.TOP);
							graphic.drawString("" + temp.getScore(), x2, y,
									Graphics.RIGHT | Graphics.TOP);
						}
						
						f = graphic.getFont();
						
						y = y + f.getHeight()+2;
						
						index++;
					}
					
					
				} else {
					if (this.records.getRecords().getRepository().size()> index){
					temp = (Record) this.records.getRecords()
					.getRepository().elementAt(index);
					graphic.drawString(temp.getName(), x1, y, Graphics.LEFT
							| Graphics.TOP);
					graphic.drawString("" + temp.getScore(), x2, y,
							Graphics.RIGHT | Graphics.TOP);
					}
				}
				
				Font f = graphic.getFont();
				
				y = y + f.getHeight()+2;
				
				index++;
				
			}
			this.cursor = null;
			System.gc();
		} else {
			if (this.isNewRecord()) {
				this.cursor = Image.createImage("/labyrinth/images/setas.png");
				this.drawCursor(x1,y,graphic);
				this.cursor = null;
				System.gc();
				graphic.drawString("" + this.newScore, x2, y, Graphics.RIGHT
						| Graphics.TOP);
			} else {
				graphic.setColor(255, 255, 255);
				graphic.drawString("No Records!", this.getWidth() / 2,
						this.getHeight() / 2, Graphics.BASELINE
								| Graphics.HCENTER);
			}
		}		

		graphic.setColor(100, 100, 255);
		
		
		
		if (this.isNewRecord()) {
			graphic.drawString("Add", 2, 120, 0);
			
		}

		graphic.setColor(255, 255, 255);
		graphic.drawString("Back", 102, 120, 0);
		graphic.setFont(Font.getFont(Font.FACE_MONOSPACE, Font.STYLE_PLAIN,
				Font.SIZE_LARGE));
		
		graphic.drawString("Records", 64, 5, Graphics.TOP | Graphics.HCENTER);
		
		}
		catch(Exception e){
			System.out.println(e);
		}
		}

	/**
	 * Metodo que captura a tecla pressionada.
	 */
	protected void keyReleased(int keyCode) {

		switch (keyCode) {

		case KEY_SOFTKEY1:
			// OK
			if (this.isNewRecord()) {
				
				this.setNewRecord(false);
				this.finalName();
				this.records.addRecord(this.getNewName(),this.getNewScore());
				this.records.write();
				
			}
			repaint();
			break;
		case KEY_SOFTKEY2:
			//Back
			this.main.getMain().getDisplay().setCurrent(this.main);
			break;
		case KEY_NUM2:
			//UP
			if (this.isNewRecord()) {
				
				this.setCharacterPosition(0);
				this.setName();
			}
			repaint();
			break;
		case KEY_NUM8:
			//down
			if (this.isNewRecord()) {
				
				this.setCharacterPosition(1);
				this.setName();
			}
			repaint();
			break;
		case KEY_NUM4:
			//left
			if (this.isNewRecord()) {
				this.setName();
				this.setCursorPosition(1);
			}
			repaint();
			break;
		case KEY_NUM6:
			//right
			if (this.isNewRecord()) {
				this.setName();
				this.setCursorPosition(0);
			}
			repaint();
			break;

		default:
			if (this.isNewRecord()) {
				int action = getGameAction(keyCode);
				switch (action) {
				case UP:
					//				UP
					
					this.setCharacterPosition(0);
					this.setName();
					break;
				case DOWN:
					//				down
					
					this.setCharacterPosition(1);
					this.setName();
					break;
				case LEFT:
					//				left
					this.setName();
					this.setCursorPosition(1);
					break;
				case RIGHT:
					//				right
					this.setName();
					this.setCursorPosition(0);
					break;
				default:
					break;
				}
				repaint();
			}

			break;

		}
		
	}

	/**
	 * @return retorna o atributo records.
	 */
	public RecordRegistry getRecords() {
		return records;
	}

	/**
	 * @param records
	 *            objeto que substituir o existente.
	 */
	public void setRecords(RecordRegistry records) {
		this.records = records;
	}

	/**
	 * Mtodo que retorna os nomes dos recordistas.
	 * 
	 * @return uma String representando todos os nomes dos recordistas.
	 */
	/*
	 * public String getRecordsNames() { String retorno = ""; int index = 0;
	 * while (index < this.records.getRecords().getRepository().size()) { Record
	 * temp = (Record) this.records.getRecords().getRepository()
	 * .elementAt(index); retorno = retorno + temp.getName() + " "; index++; }
	 * return retorno; }
	 */

	/**
	 * @return Returns the newName.
	 */
	public String getNewName() {
		return newName;
	}

	/**
	 * @param newName
	 *            The newName to set.
	 */
	public void setNewName(String newName) {
		this.newName = newName;
	}

	/**
	 * @return Returns the newScore.
	 */
	public int getNewScore() {
		return newScore;
	}

	/**
	 * @param newScore
	 *            The newScore to set.
	 */
	public void setNewScore(int newScore) {
		this.newScore = newScore;
	}

	/**
	 * @return Returns the isNewRecord.
	 */
	public boolean isNewRecord() {
		return isNewRecord;
	}

	/**
	 * @param isNewRecord
	 *            The isNewRecord to set.
	 */
	public void setNewRecord(boolean isRecord) {

		this.isNewRecord = isRecord;
		this.characterPosition = 0;
		this.cursorPosition = 0;
	}

	/**
	 * @return Returns the main.
	 */
	public LabyrinthMenu getMain() {
		return main;
	}

	/**
	 * @return Returns the characterPosition.
	 */
	public int getCharacterPosition() {
		return characterPosition;
	}

	/**
	 * @param characterPosition
	 *            The characterPosition to set.
	 */
	public void setCharacterPosition(int direction) {

		switch (direction) {
		case 0:
			//Prxima
			if (((this.getCharacterPosition() + 1) >= 0)
					&& ((this.getCharacterPosition() + 1) < this.letters.length)) {
				this.characterPosition = characterPosition + 1;
			}
			else{
				this.characterPosition = 0;
			}
			break;
		case 1:
			//Anterior
			if (((this.getCharacterPosition() - 1) >= 0)
					&& ((this.getCharacterPosition() - 1) < this.letters.length)) {
				this.characterPosition = characterPosition - 1;
			}
			else{
				this.characterPosition = this.letters.length - 1;
			}
			break;
		default:
			break;
		}

	}

	/**
	 * @return Returns the cursorPosition.
	 */
	public int getCursorPosition() {
		return cursorPosition;
	}

	/**
	 * @param cursorPosition
	 *            The cursorPosition to set.
	 */
	public void setCursorPosition(int direction) {
		switch (direction) {
		case 0:
			//Proxima posicao
			if ((this.getCursorPosition() + 1 >= 0)
					&& (this.getCursorPosition() + 1 < 5)) {
				this.cursorPosition = this.cursorPosition + 1;
			
			}
			this.setExistentCharacterPosition();
			break;
		case 1:
			//Posicao anterior
			if ((this.getCursorPosition() - 1 >= 0)
					&& (this.getCursorPosition() - 1 < 5)) {
				this.cursorPosition = this.cursorPosition - 1;
				
			}
			this.setExistentCharacterPosition();
			break;
		default:
			break;
		}

	}

	public void drawCursor(int x1, int y, Graphics graphic) {

		for (int i = 0; i < 5; i++) {
			if (i == this.getCursorPosition()) {
				graphic.drawImage(cursor, (x1 + (i * 10)), y-5, Graphics.LEFT
						| Graphics.TOP);
				graphic.drawString(""
						+ this.letters[this.getCharacterPosition()], x1
						+ (i * 10), y, Graphics.LEFT | Graphics.TOP);
			} else {
				if (i < this.newName.length() && !this.newName.substring(i,i+1).equals(" ")) {
					graphic.drawString("" + this.newName.charAt(i), x1
							+ (i * 10), y, Graphics.LEFT | Graphics.TOP);
				} else {
					graphic.drawString("_", x1 + (i * 10), y, Graphics.LEFT
							| Graphics.TOP);
				}
			}
		}

	}
	
	public void setName(){
		
		String init = this.newName.substring(0,this.getCursorPosition());
		System.out.println("init :" + init);
		String end = "";
		if (this.getCursorPosition() < 5){
		end = this.newName.substring(this.getCursorPosition()+1);
		}
		System.out.println("end :"+end);
		this.newName = init + this.letters[this.getCharacterPosition()] +end;
		//this.characterPosition = 0;
		System.out.println("name  ::" +newName);
	}
	
	public void setExistentCharacterPosition(){
		int index  = this.getCharacterIndex(this.newName.charAt(this.getCursorPosition()));
		this.characterPosition = index;
		
	}
	
	public int getCharacterIndex(char a){
		int index = 0;
		boolean find = false;
		while(!find && index < this.letters.length){
			if (this.letters[index]==a){
				find = true;
			}
			else{
				index = index +1;
			}
		}
		return index;
	}
	
	public void finalName(){
		//this.setName();
		this.setCursorPosition(1);
		String temp = "";
		for (int i=0; i<5; i++){
			temp = ""+this.newName.charAt(i);
			System.out.println(i+":"+temp);
		}
		System.out.println(temp);
		//this.newName = temp;
	}

}