package labyrinth.menu;


import java.io.IOException;

import javax.microedition.lcdui.Font;
import javax.microedition.lcdui.Graphics;
import javax.microedition.lcdui.Image;

import labyrinth.settings.GameSettings;
import labyrinth.settings.Sound;
import labyrinth.settings.Vibracall;

import com.nokia.mid.ui.FullCanvas;


/*
 * Mostra uma tela com as atuais configuraes do jogo com relao a som e
 * vibrao. D opo de habilitar ou no o som e o vibracal do celular no jogo.
 */
public class SettingsScreen extends FullCanvas {

	/**
	 * Atributo que armazena a opo On/Off do som.
	 */
	private boolean sound;

	/**
	 * Atributo que armazena a opo On/Off do vibracall.
	 */
	private boolean vibracall;
	
	/**
	 * Atributo que armazena a opo de level.
	 */
	private int level;

	/**
	 * Atributo que contm o MIDlet ativo do jogo.
	 */
	private LabyrinthMenu main;
	
	/**
	 * Atributo que contem uma imagem a ser impressa.
	 */
	private Image fundo;
	
	/**
	 * Atributo que contem uma imagem a ser impressa.
	 */
	private Image botao;

	/**
	 * FLAG para orientar o botao de selecao.
	 */
	private int posicao;

	/**
	 * construtor da classe que instancia um objeto.
	 */	
	
	private GameSettings gameSettings;
	
	public SettingsScreen(LabyrinthMenu main) {
		
		try {
			
			this.main = main;	
			
			//Posicao inicial do cursor do menu
			this.posicao = 38;
			
			// VAI SER CARREGADO DO ARQUIVO
			this.gameSettings = new GameSettings();
			this.sound = this.gameSettings.getSound();
			this.level = this.gameSettings.getLevel();
			if(this.level == 0){
				this.level = 3;
			}
			this.vibracall = this.gameSettings.getVibracall();			

			//definindo o background e o cursor
			fundo = null;
			botao = null;

			// repintar a tela com as conf atuais
			repaint();

		} catch (IllegalArgumentException e) {			
			e.printStackTrace();
		} catch (NullPointerException e) {			
			e.printStackTrace();
		}
	}

	protected void paint(Graphics graphics) {

		graphics.setFont(Font.getFont(Font.FACE_MONOSPACE, Font.STYLE_PLAIN, Font.SIZE_MEDIUM));
		//define a cor branca como a padrao
		graphics.setColor(0, 0, 0);
		graphics.fillRect(0, 118, 128,10);

		try {
			//Pinta o fundo e o cursor
			this.fundo = Image.createImage("/labyrinth/images/default.png");
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		graphics.drawImage(this.fundo, 0, 0, Graphics.LEFT | Graphics.TOP);
		this.fundo = null;
		System.gc();
		try {
			this.botao = Image.createImage("/labyrinth/images/sprite.png");
		} catch (IOException e1) {
			// TODO Auto-generated catch block
			e1.printStackTrace();
		}
		graphics.drawImage(this.botao, 5, this.posicao, Graphics.LEFT | Graphics.TOP);
		this.botao = null;
		System.gc();
		

		//imprime as opcoes
		graphics.setColor(255,255,255);
		graphics.drawString("Sound", 20, 35, 0);
		graphics.drawString("Vibra", 20, 60, 0);
		graphics.drawString("Level", 20, 85, 0);
		graphics.setColor(255, 255, 255);
		graphics.drawString("ON  OFF", 70, 35, 0);
		graphics.drawString("ON  OFF", 70, 60, 0);
		graphics.drawString("1   2   3", 70 ,85, 0);

		//redefine a cor para verde
		graphics.setColor(0, 255, 0);

		//faz as conferencias e pinta as opcoes selecionadas
		if(this.sound)
			graphics.drawString("ON", 70, 35, 0);
		else
			graphics.drawString("OFF", 94, 35, 0);

		if(this.vibracall)
			graphics.drawString("ON", 70, 60, 0);
		else
			graphics.drawString("OFF", 94, 60, 0);

		if(this.level == 1)
			graphics.drawString("1", 70, 85, 0);
		else if(this.level == 2)
			graphics.drawString("2", 87, 85, 0);
		else
			graphics.drawString("3", 104, 85, 0);


		// imprimi as opcoes OK e BACK
		graphics.setColor(255,255,255);
		graphics.setFont(Font.getFont(Font.FACE_MONOSPACE, Font.STYLE_PLAIN, Font.SIZE_SMALL));
		graphics.drawString("OK", 2, 120, 0);
		graphics.drawString("Back", 102, 120, 0);
		
		graphics.setFont(Font.getFont(Font.FACE_MONOSPACE, Font.STYLE_PLAIN, Font.SIZE_LARGE));
		graphics.drawString("Settings", 64, 5, Graphics.TOP | Graphics.HCENTER);	
		
	}

	/**
	 * Metodo que captura as teclas de movimentacao
	 */
	public void keyPressed(int keyCode) {
		int key = getGameAction(keyCode);
		switch (key) {
		case UP:
			// MOVER O CURSOR PARA CIMA
			if(this.posicao == 38)
				this.posicao = 88;
			else this.posicao = this.posicao - 25;
			repaint();

			break;
		case DOWN:
			//MOVER O CURSOR PARA BAIXO
			if(this.posicao == 88)
				this.posicao = 38;
			else this.posicao = this.posicao + 25;
			repaint();

			break;
		case LEFT:
			//ALTERAR A OPCAO ATUAL
			this.selectedMenu(false);

			break;
		case RIGHT:
			//ALTERAR A OPCAO ATUAL
			this.selectedMenu(true);

			break;
		default:

			break;

		}

	}

	/**
	 * Metodo que captura as SoftKeys
	 */
	public void keyReleased(int keyRelease){

		switch (keyRelease) {
		case KEY_SOFTKEY1:
			//SALVAR CONFIGURACOES
			
			this.saveSettings();
			
			this.main.getMain().getDisplay().setCurrent(this.main);
			break;
		case KEY_SOFTKEY2:
			//CANCELAR E DEIXAR ATUAL
			this.main.getMain().getDisplay().setCurrent(this.main);
			break;

		}
	}

	/**
	 * Mtodo que verifica qual o menu foi selecionado.
	 *
	 */
	public void selectedMenu(boolean b) {

		if(this.posicao == 38){
			if(this.sound){

				//confirmar se o som vai parar...
				Sound s = new Sound();
				s.playTone(120, 1, 0);
				this.sound = false;
			}
			else{
				this.sound = true;
				Sound s = new Sound();
				s.playTone(120, 30, 100);
			}

		}else if(this.posicao == 63){
			if(this.vibracall)
				this.vibracall = false;
			else {
				this.vibracall = true;
				Vibracall.vibra(99, 200);
			}
		} else {
			if(b){
				if(this.level == 3)
					this.level = 1;
				else
					this.level = this.level + 1;

			}else {
				if(this.level == 1)
					this.level = 3;
				else
					this.level = this.level - 1;

			}
		}
		repaint();
	}

	/**
	 * Mtodo que inicializa as opes de configurao.
	 */
	public void initializeOptions() {
		this.gameSettings.initialize();
	}

	/**
	 * Mtodo que mostra as opes de som.
	 */
	/*public void showSoundOptions() {

	}*/

	/**
	 * Mtodo que mostra as opes de vibrar.
	 *
	 */
	/*public void showVibracallOptions() {

	}*/

	/**
	 * Mtodo que retorna se o som est habilitado ou no.
	 *
	 * @return retorna o atributo sound.
	 */
	public boolean getSound() {
		return sound;
	}

	/**
	 * Mtodo que modifica o atributo sound pelo passado como parmetro.
	 *
	 * @param sound
	 *            boolean que substituir o atributo sound.
	 */
	public void setSound(boolean sound) {
		this.sound = sound;
	}

	/**
	 * Mtodo que retorna se a opo de vibrar est habilitada ou no
	 *
	 * @return retorna o atributo vibracall.
	 */
	public boolean getVibracall() {
		return vibracall;
	}

	/**
	 * Mtodo que modifica o atributo vibracall pelo passado como parmetro.
	 *
	 * @param vibracall
	 *            boolean que substituir o atributo vibracall.
	 */
	public void setVibracall(boolean vibracall) {
		this.vibracall = vibracall;
	}

	/**
	 * Mtodo que retorna se a opo de som est habilitada.
	 *
	 * @return true se o som estiver habilitado ou false caso contrrio.
	 */
	public boolean getSoundOn() {
		boolean retorno = sound;
		return retorno;
	}

	/**
	 * Mtodo que retorna se a opo de vibrar est habilitada.
	 *
	 * @return true se o vibrar estiver habilitado ou false caso contrrio.
	 */
	public boolean getVibracallOn() {
		boolean retorno = this.vibracall;
		return retorno;
	}

	/**
	 * Mtodo que salva as configuraes.
	 */
	public void saveSettings() {
		this.gameSettings.setLevel(new Integer(this.level).byteValue());
		this.gameSettings.setSound(this.sound);
		this.gameSettings.setVibracall(this.vibracall);
		
		this.gameSettings.write();
	}
}