package labyrinth.records;


import java.util.Vector;


/*
 * Classe responsvel pela criao do repositrio que ir armazenar os recordes
 * antes deles serem escritos no arquivo. Apenas armazena, no verifica que dado
 * pode ou no ser armazenado
 */
public class RecordRepository {

	/**
	 * Atributo que armazena todos os records.
	 */
	private Vector repository;

	private String fileName;

	/* MUDAR NO DIAGRAMA DE CLASSES****************************** */

	/**
	 * Construtor da classe que instancia um novo objeto.
	 */
	public RecordRepository(String fileName) {
		this.fileName = fileName;
		this.repository = new Vector();		
	}

	/* VERIFICAR SE O RECORD VAI SER SHORT OU INT!!!!!!!!!! */

	/**
	 * Mtodo que verifica se a pontuao especificada como parmetro  um novo
	 * recorde.
	 * 
	 * @param record
	 *            pontuao a ser verificada.
	 * 
	 * @return true se a pontuao  um novo recorde e false caso contrrio.
	 */
	public boolean isRecord(int record) {
		boolean retorno = false;
		if (this.repository.size() < 6) {			
			retorno = true;
		} else {
			int index = 0;
			while (index < this.repository.size()) {
				if (record > ((Record) this.repository.elementAt(index))
						.getScore()) {
					retorno = true;
				}
				index++;
			}
		}
		return retorno;
	}

	/**
	 * Mtodo que adiciona um novo recorde, que ja foi verificado ser um novo
	 * recorde.
	 * 
	 * @param name
	 *            nome do novo recordista.
	 * 
	 * @param score
	 *            pontuao do novo recordista.
	 */
	public void addRecord(String name, int score) {
		if (this.repository.size() == 0) {
			this.repository.addElement(new Record(name, score));
		} else {
			int index = 0;
			while (index < this.repository.size()
					&& ((Record) this.repository.elementAt(index)).getScore() >= score) {
				index++;
			}
			this.repository.insertElementAt(new Record(name, score), index);
			this.removeScore();
		}
	}

	/**
	 * Mtodo que remove os recordes com posio maior que 5. Esse mtodo ser
	 * sempre chamado quando se adicionar novo recorde.
	 */
	public void removeScore() {
		if (this.repository.size() > 5) {
			int index = 5;
			while (index < this.repository.size()) {
				this.repository.removeElementAt(index);
				index++;
			}
		}
	}

	/**
	 * Mtodo que retorna um Vector com todos os recordes.
	 * 
	 * @return Returns o atributo repository.
	 */
	public Vector getRepository() {
		return repository;
	}

	/* ADICIONAR ISSO NO DIAGRAMA DE CLASSES******************** */

	/**
	 * @return Returns the fileName.
	 */
	public String getFileName() {
		return fileName;
	}

	/**
	 * @param fileName
	 *            The fileName to set.
	 */
	public void setFileName(String fileName) {
		this.fileName = fileName;
	}
	
	/**
	 * Mtodo que retorna em que ndice(em que posio) um novo recorde ser adicionado
	 * 
	 * @param score   Integer com o novo score obtido
	 * 
	 * @return		  Integer com a posio obtida com o recorde
	 */
	public int getNewRecordIndex(int score){
		int index = 0;
		if (this.repository.size() == 0) {
			index = 0;
		} else {
			int i = 0;
			while (i < this.repository.size()
					&& ((Record) this.repository.elementAt(i)).getScore() >= score) {
				i++;
			}
			index = i;
			
		}
		return index;
	}
}